// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
// SPDX-License-Identifier: BSD-3-Clause

#ifndef IDYNTREE_ESTIMATION_ATTITUDE_ESTIMATOR_UTILS_H
#define IDYNTREE_ESTIMATION_ATTITUDE_ESTIMATOR_UTILS_H

#ifdef __DEPRECATED
  #warning <iDynTree/Estimation/AttitudeEstimatorUtils.h> is deprecated. Please use <iDynTree/AttitudeEstimatorUtils.h>. To disable this warning use -Wno-deprecated.
#endif

#include <iDynTree/AttitudeEstimatorUtils.h>

#endif

