// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
// SPDX-License-Identifier: BSD-3-Clause
#ifndef IDYNTREE_ESTIMATION_BIPED_FOOT_CONTACT_CLASSIFIER_H
#define IDYNTREE_ESTIMATION_BIPED_FOOT_CONTACT_CLASSIFIER_H

#ifdef __DEPRECATED
  #warning <iDynTree/Estimation/BipedFootContactClassifier.h> is deprecated. Please use <iDynTree/BipedFootContactClassifier.h>. To disable this warning use -Wno-deprecated.
#endif

#include <iDynTree/BipedFootContactClassifier.h>

#endif